import React, { useState, useEffect } from 'react';
import { FaCloudDownloadAlt, FaGoogleDrive } from 'react-icons/fa';
import { openCandApi } from '../api';
import type { OpenCandDataAvailabilityStats, OpenCandDatabaseStats } from '../api/apiModels';
import Card from '../shared/Card';
import ErrorPage from './ErrorPage';

const DataStatsPage: React.FC = () => {
  const [stats, setStats] = useState<OpenCandDataAvailabilityStats | null>(null);
  const [dbStats, setDbStats] = useState<OpenCandDatabaseStats | null>(null);
  const [loading, setLoading] = useState(true);
  const [dbLoading, setDbLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);
  const [dbError, setDbError] = useState<string | null>(null);

  useEffect(() => {
    const fetchStats = async () => {
      try {
        setLoading(true);
        const data = await openCandApi.getDataAvailabilityStats();
        setStats(data);
      } catch (err) {
        setError('Erro ao carregar matriz de disponibilidade de dados');
        console.error('Error fetching data availability stats:', err);
      } finally {
        setLoading(false);
      }
    };
    const fetchDbStats = async () => {
      try {
        setDbLoading(true);
        const dbData = await openCandApi.getDatabaseTechStats();
        setDbStats(dbData);
      } catch (err) {
        setDbError('Erro ao carregar estatísticas técnicas do banco de dados');
        console.error('Error fetching database tech stats:', err);
      } finally {
        setDbLoading(false);
      }
    };
    fetchStats();
    fetchDbStats();
  }, []);

  if (loading) {
    return (
      <div className="flex items-center justify-center min-h-[40vh]">
        <div className="backdrop-blur-md bg-white/90 rounded-2xl shadow-xl p-8 max-w-md w-full border border-white/30 flex flex-col items-center">
          <div className="animate-spin rounded-full h-10 w-10 border-4 border-indigo-600 border-t-transparent mb"></div>
          <p className="text-base text-gray-700">Carregando dados...</p>
        </div>
      </div>
    );
  }

  if (error) {
    return (
      <ErrorPage
        title="Erro"
        description={error}
        helperText="Tente novamente ou volte para a página inicial."
      />
    );
  }

  if (!stats) {
    return (
      <div className="min-h-screen bg-gray-50 flex items-center justify-center">
        <p className="text-lg text-gray-700">Nenhum dado disponível</p>
      </div>
    );
  }

  // Get all unique years from all data types
  const allYears = new Set<number>();
  Object.values(stats).forEach((yearArray: number[]) => {
    yearArray.forEach((year: number) => allYears.add(year));
  });
  const sortedYears = Array.from(allYears).sort((a, b) => b - a);

  const dataTypes = [
    { key: 'candidatos', label: 'Candidatos', icon: '👤' },
    { key: 'bemCandidatos', label: 'Bens de Candidatos', icon: '💰' },
    { key: 'despesaCandidatos', label: 'Despesas de Candidatos', icon: '💸' },
    { key: 'receitaCandidatos', label: 'Receitas de Candidatos', icon: '💵' },
    { key: 'redeSocialCandidatos', label: 'Redes Sociais', icon: '📱' },
    { key: 'fotosCandidatos', label: 'Fotos de Candidatos (API)', icon: '📸' },
  ];

  return (
    <div className="min-h-screen py-20 px-4 hover:cursor-default">
      <div className="max-w-7xl mx-auto">
        {/* Header */}
        <div className="text-center mb-12 animate-slide-in-left">
          <h1 className="text-4xl md:text-6xl font-bold mb-4 text-white">
            Disponibilidade de Dados
          </h1>
          <p className="text-xl text-gray-400">
            Visualize a disponibilidade dos dados por ano em nossa base
          </p>
          <div className="w-32 h-1 bg-gradient-to-r from-indigo-400 to-purple-400 mx-auto mt-6 rounded-full"></div>
        </div>

        {/* Download DB Dump Section */}
        <div className="flex justify-center mb-10 animate-slide-in-left backdrop-blur-xs bg-gray-800/10 rounded-xl shadow-lg hover:shadow-xl transform transition-all duration-200 overflow-hidden ring-1 ring-gray-700 hover:ring-indigo-300 px-8 py-6 flex flex-col md:flex-row items-center gap-4 max-w-xl-auto">
          <div className="flex items-center gap-3 mb-2 md:mb-0">
            <FaCloudDownloadAlt className="text-3xl text-green-400" />
            <span className="text-lg font-semibold text-white">Download do Dump do Banco de Dados</span>
          </div>
          <a
            href="https://drive.google.com/file/d/1cfMItrsAdv8y8YUNp04D33s6pYrRbmDn/view?usp=sharing"
            target="_blank"
            rel="noopener noreferrer"
            className="inline-flex items-center gap-2 py-2 px-5 bg-gradient-to-r from-indigo-500 to-purple-600 text-white font-semibold rounded-lg hover:from-indigo-600 hover:to-purple-700 transition-all duration-300 transform shadow-lg hover:shadow-xl"
          >
            <FaGoogleDrive className="text-xl" />
            Google Drive
          </a>
        </div>

        {/* Stats Cards */}
        <div className="grid grid-cols-1 md:grid-cols-3 gap-6 mb-12">
          <Card hasAnimation={true} className="bg-gray-800/10 rounded-xl">
            <div className="text-center">
              <div className="text-3xl mb-2">📊</div>
              <div className="text-2xl font-bold text-white">{dataTypes.length}</div>
              <div className="text-gray-400">Tipos de Dados</div>
            </div>
          </Card>
          <Card hasAnimation={true} className="bg-gray-800/10 rounded-xl">
            <div className="text-center">
              <div className="text-3xl mb-2">📅</div>
              <div className="text-2xl font-bold text-white">{sortedYears.length}</div>
              <div className="text-gray-400">Anos Disponíveis</div>
            </div>
          </Card>
          <Card hasAnimation={true} className="bg-gray-800/10 rounded-xl">
            <div className="text-center">
              <div className="text-3xl mb-2">🗓️</div>
              <div className="text-2xl font-bold text-white">
                {sortedYears.length > 0 ? `${Math.min(...sortedYears)} - ${Math.max(...sortedYears)}` : 'N/A'}
              </div>
              <div className="text-gray-400">Período</div>
            </div>
          </Card>
        </div>

        {/* Data Availability Table */}
        <div className="bg-gray-800/10 backdrop-blur-xs rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.005] transition-all duration-200 overflow-hidden ring-1 ring-gray-700 hover:ring-indigo-300">
          <div className="p-6 border-b border-gray-700/30 bg-gray-800/10">
            <h2 className="text-2xl font-bold text-white">
              Matriz de Disponibilidade
            </h2>
            <p className="text-gray-400 mt-2">
              ✅ Disponível • ❌ Não Disponível
            </p>
          </div>
          
          <div className="overflow-x-auto">
            <table className="w-full">
              <thead>
                <tr className="bg-gray-800/10">
                  <th className="text-left p-4 text-white font-semibold border-b border-gray-700/30 sticky left-0 bg-gray-800/10">
                    Tipo de Dado
                  </th>
                  {sortedYears.map((year, index) => (
                    <th 
                      key={year} 
                      className="text-center p-4 text-white font-semibold border-b border-gray-700/30 animate-slide-in-left"
                      style={{ animationDelay: `${index * 50}ms` }}
                    >
                      {year}
                    </th>
                  ))}
                </tr>
              </thead>
              <tbody>
                {dataTypes.map((dataType, rowIndex) => (
                  <tr 
                    key={dataType.key}
                    className="hover:bg-gray-800/10 transition-all duration-300 animate-slide-in-left"
                    style={{ animationDelay: `${rowIndex * 100}ms` }}
                  >
                    <td className="p-4 border-b border-gray-700/20 text-white sticky left-0 bg-gray-800/10">
                      <div className="flex items-center space-x-3">
                        <span className="text-xl">{dataType.icon}</span>
                        <span>{dataType.label}</span>
                      </div>
                    </td>
                    {sortedYears.map((year) => {
                      const isAvailable = (stats[dataType.key as keyof OpenCandDataAvailabilityStats] as number[]).includes(year);
                      return (
                        <td 
                          key={year} 
                          className="text-center p-4 border-b border-gray-700/20"
                        >
                          <div className={`inline-flex items-center justify-center w-8 h-8 rounded-full transition-all duration-100 ${
                            isAvailable 
                              ? 'bg-green-500/20 text-green-300 hover:bg-green-500/30 hover:scale-110 hover:cursor-default' 
                              : 'bg-red-500/20 text-red-300 hover:bg-red-500/30 hover:cursor-default'
                          }`}>
                            {isAvailable ? '✅' : '❌'}
                          </div>
                        </td>
                      );
                    })}
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </div>
      </div>

      {/* Database Tech Stats Section */}
      <div className="mt-20 flex justify-center">
        <div className="bg-gray-800/10 backdrop-blur-xs rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.005] transition-all duration-200 overflow-hidden ring-1 ring-gray-700 hover:ring-indigo-300 mb-12 w-full max-w-2xl">
          <div className="p-6 border-b border-gray-700/30 bg-gray-800/10">
            <h2 className="text-2xl font-bold text-white">Dados Técnicas do Banco de Dados</h2>
            <p className="text-gray-400 mt-2">Informações sobre tabelas, views materializadas e índices</p>
          </div>
          {dbLoading ? (
            <div className="flex items-center justify-center p-8">
              <div className="animate-spin rounded-full h-8 w-8 border-4 border-indigo-600 border-t-transparent mr-4"></div>
              <span className="text-gray-300">Carregando dados do banco de dados...</span>
            </div>
          ) : dbError ? (
            <div className="p-8 text-red-400">{dbError}</div>
          ) : dbStats ? (
            <div className="p-6 space-y-10">
              {/* Tables */}
              <div>
                <h3 className="text-xl font-semibold text-white mb-2">Tabelas</h3>
                <div className="overflow-x-auto max-h-112" style={{maxHeight: '32rem'}}>
                  <table className="w-full text-left border-collapse">
                    <thead>
                      <tr className="bg-gray-800/10">
                        <th className="p-3 text-white font-semibold border-b border-gray-700/30">Nome</th>
                        <th className="p-3 text-white font-semibold border-b border-gray-700/30">Tamanho Total</th>
                        <th className="p-3 text-white font-semibold border-b border-gray-700/30">Entradas</th>
                      </tr>
                    </thead>
                    <tbody>
                      {dbStats.tables.map((table) => {
                        const name = table.name.replace(/^public\./, '');
                        const sizeMB = table.totalSize / 1024 / 1024;
                        const sizeDisplay = sizeMB > 1024
                          ? `${(sizeMB / 1024).toFixed(2)} GB`
                          : `${sizeMB.toFixed(2)} MB`;
                        return (
                          <tr key={table.name} className="hover:bg-gray-800/10 transition-all duration-200">
                            <td className="p-3 text-white">{name}</td>
                            <td className="p-3 text-gray-300">{sizeDisplay}</td>
                            <td className="p-3 text-gray-300">{table.entries.toLocaleString()}</td>
                          </tr>
                        );
                      })}
                      {/* Total row */}
                      {(() => {
                        const totalSize = dbStats.tables.reduce((acc, t) => acc + t.totalSize, 0);
                        const totalEntries = dbStats.tables.reduce((acc, t) => acc + t.entries, 0);
                        const totalMB = totalSize / 1024 / 1024;
                        const totalDisplay = totalMB > 1024
                          ? `${(totalMB / 1024).toFixed(2)} GB`
                          : `${totalMB.toFixed(2)} MB`;
                        return (
                          <tr className="font-bold bg-gray-900/30">
                            <td className="p-3 text-white">Total</td>
                            <td className="p-3 text-gray-300">{totalDisplay}</td>
                            <td className="p-3 text-gray-300">{totalEntries.toLocaleString()}</td>
                          </tr>
                        );
                      })()}
                    </tbody>
                  </table>
                </div>
              </div>
              {/* Materialized Views */}
              <div>
                <h3 className="text-xl font-semibold text-white mb-2">Views Materializadas</h3>
                <div className="overflow-x-auto max-h-96" style={{maxHeight: '28rem'}}>
                  <table className="w-full text-left border-collapse">
                    <thead>
                      <tr className="bg-gray-800/10">
                        <th className="p-3 text-white font-semibold border-b border-gray-700/30">Nome</th>
                        <th className="p-3 text-white font-semibold border-b border-gray-700/30">Tamanho Total</th>
                        <th className="p-3 text-white font-semibold border-b border-gray-700/30">Entradas</th>
                      </tr>
                    </thead>
                    <tbody>
                      {dbStats.materializedViews.map((view) => {
                        const name = view.name.replace(/^public\./, '');
                        const sizeMB = view.totalSize / 1024 / 1024;
                        const sizeDisplay = sizeMB > 1024
                          ? `${(sizeMB / 1024).toFixed(2)} GB`
                          : `${sizeMB.toFixed(2)} MB`;
                        return (
                          <tr key={view.name} className="hover:bg-gray-800/10 transition-all duration-200">
                            <td className="p-3 text-white">{name}</td>
                            <td className="p-3 text-gray-300">{sizeDisplay}</td>
                            <td className="p-3 text-gray-300">{view.entries.toLocaleString()}</td>
                          </tr>
                        );
                      })}
                    </tbody>
                  </table>
                </div>
              </div>
              {/* Indexes */}
              <div>
                <h3 className="text-xl font-semibold text-white mb-2">Índices</h3>
                <div className="overflow-x-auto max-h-96 flex justify-center" style={{maxHeight: '28rem'}}>
                  <table className="w-auto text-left border-collapse mx-auto">
                    <thead>
                      <tr className="bg-gray-800/10">
                        <th className="p-3 text-white font-semibold border-b border-gray-700/30">Quantidade</th>
                        <th className="p-3 text-white font-semibold border-b border-gray-700/30">Tamanho Total</th>
                      </tr>
                    </thead>
                    <tbody>
                      <tr>
                        <td className="p-3 text-gray-300">{dbStats.indexes.amount}</td>
                        {(() => {
                          const sizeMB = dbStats.indexes.size / 1024 / 1024;
                          const sizeDisplay = sizeMB > 1024
                            ? `${(sizeMB / 1024).toFixed(2)} GB`
                            : `${sizeMB.toFixed(2)} MB`;
                          return <td className="p-3 text-gray-300">{sizeDisplay}</td>;
                        })()}
                      </tr>
                    </tbody>
                  </table>
                </div>
              </div>
            </div>
          ) : null}
        </div>
      </div>
    </div>
  );
};

export default DataStatsPage;
